==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/DatasourceSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * DatasourceSet details of datasource to be backed up
 * @property datasourceType DatasourceType of the resource.
 * @property objectType Type of Datasource object, used to initialize the right inherited type
 * @property resourceID Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
 * @property resourceLocation Location of datasource.
 * @property resourceName Unique identifier of the resource in the context of parent.
 * @property resourceType Resource Type of Datasource.
 * @property resourceUri Uri of the resource.
 */
public data class DatasourceSetArgs(
    public val datasourceType: Output<String>? = null,
    public val objectType: Output<String>? = null,
    public val resourceID: Output<String>,
    public val resourceLocation: Output<String>? = null,
    public val resourceName: Output<String>? = null,
    public val resourceType: Output<String>? = null,
    public val resourceUri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs =
        com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs.builder()
            .datasourceType(datasourceType?.applyValue({ args0 -> args0 }))
            .objectType(objectType?.applyValue({ args0 -> args0 }))
            .resourceID(resourceID.applyValue({ args0 -> args0 }))
            .resourceLocation(resourceLocation?.applyValue({ args0 -> args0 }))
            .resourceName(resourceName?.applyValue({ args0 -> args0 }))
            .resourceType(resourceType?.applyValue({ args0 -> args0 }))
            .resourceUri(resourceUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatasourceSetArgs].
 */
@PulumiTagMarker
public class DatasourceSetArgsBuilder internal constructor() {
    private var datasourceType: Output<String>? = null

    private var objectType: Output<String>? = null

    private var resourceID: Output<String>? = null

    private var resourceLocation: Output<String>? = null

    private var resourceName: Output<String>? = null

    private var resourceType: Output<String>? = null

    private var resourceUri: Output<String>? = null

    /**
     * @param value DatasourceType of the resource.
     */
    @JvmName("qetlsoofwdkkmglw")
    public suspend fun datasourceType(`value`: Output<String>) {
        this.datasourceType = value
    }

    /**
     * @param value Type of Datasource object, used to initialize the right inherited type
     */
    @JvmName("mtiumilwjlnfqngs")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
     */
    @JvmName("xvlmwwbfoaflgvhu")
    public suspend fun resourceID(`value`: Output<String>) {
        this.resourceID = value
    }

    /**
     * @param value Location of datasource.
     */
    @JvmName("ndmixqqtbktpmrdo")
    public suspend fun resourceLocation(`value`: Output<String>) {
        this.resourceLocation = value
    }

    /**
     * @param value Unique identifier of the resource in the context of parent.
     */
    @JvmName("kjjomeqluxeylxjx")
    public suspend fun resourceName(`value`: Output<String>) {
        this.resourceName = value
    }

    /**
     * @param value Resource Type of Datasource.
     */
    @JvmName("squqfkqjxjibcbka")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Uri of the resource.
     */
    @JvmName("kewydqyolnwmfeyg")
    public suspend fun resourceUri(`value`: Output<String>) {
        this.resourceUri = value
    }

    /**
     * @param value DatasourceType of the resource.
     */
    @JvmName("thxfcdsrpfmianwm")
    public suspend fun datasourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasourceType = mapped
    }

    /**
     * @param value Type of Datasource object, used to initialize the right inherited type
     */
    @JvmName("hvalkurbqtaydtea")
    public suspend fun objectType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
     */
    @JvmName("heaoaqnufmwexvas")
    public suspend fun resourceID(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceID = mapped
    }

    /**
     * @param value Location of datasource.
     */
    @JvmName("cgxkmuqmaamwaxjy")
    public suspend fun resourceLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceLocation = mapped
    }

    /**
     * @param value Unique identifier of the resource in the context of parent.
     */
    @JvmName("qtcpntbhsendhuig")
    public suspend fun resourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceName = mapped
    }

    /**
     * @param value Resource Type of Datasource.
     */
    @JvmName("smafiqawrrebrcmk")
    public suspend fun resourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Uri of the resource.
     */
    @JvmName("vgpawqhgggcvjiqd")
    public suspend fun resourceUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceUri = mapped
    }

    internal fun build(): DatasourceSetArgs = DatasourceSetArgs(
        datasourceType = datasourceType,
        objectType = objectType,
        resourceID = resourceID ?: throw PulumiNullFieldException("resourceID"),
        resourceLocation = resourceLocation,
        resourceName = resourceName,
        resourceType = resourceType,
        resourceUri = resourceUri,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/dataprotection/kotlin/inputs/DatasourceSetArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dataprotection.kotlin.inputs

import com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * DatasourceSet details of datasource to be backed up
 * @property datasourceType DatasourceType of the resource.
 * @property objectType Type of Datasource object, used to initialize the right inherited type
 * @property resourceID Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
 * @property resourceLocation Location of datasource.
 * @property resourceName Unique identifier of the resource in the context of parent.
 * @property resourceType Resource Type of Datasource.
 * @property resourceUri Uri of the resource.
 */
public data class DatasourceSetArgs(
    public val datasourceType: Output<String>? = null,
    public val objectType: Output<String>? = null,
    public val resourceID: Output<String>,
    public val resourceLocation: Output<String>? = null,
    public val resourceName: Output<String>? = null,
    public val resourceType: Output<String>? = null,
    public val resourceUri: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs> {
    override fun toJava(): com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs =
        com.pulumi.azurenative.dataprotection.inputs.DatasourceSetArgs.builder()
            .datasourceType(datasourceType?.applyValue({ args0 -> args0 }))
            .objectType(objectType?.applyValue({ args0 -> args0 }))
            .resourceID(resourceID.applyValue({ args0 -> args0 }))
            .resourceLocation(resourceLocation?.applyValue({ args0 -> args0 }))
            .resourceName(resourceName?.applyValue({ args0 -> args0 }))
            .resourceType(resourceType?.applyValue({ args0 -> args0 }))
            .resourceUri(resourceUri?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [DatasourceSetArgs].
 */
@PulumiTagMarker
public class DatasourceSetArgsBuilder internal constructor() {
    private var datasourceType: Output<String>? = null

    private var objectType: Output<String>? = null

    private var resourceID: Output<String>? = null

    private var resourceLocation: Output<String>? = null

    private var resourceName: Output<String>? = null

    private var resourceType: Output<String>? = null

    private var resourceUri: Output<String>? = null

    /**
     * @param value DatasourceType of the resource.
     */
    @JvmName("fdvxcqrcmssugxco")
    public suspend fun datasourceType(`value`: Output<String>) {
        this.datasourceType = value
    }

    /**
     * @param value Type of Datasource object, used to initialize the right inherited type
     */
    @JvmName("smdhskgutwaqqjie")
    public suspend fun objectType(`value`: Output<String>) {
        this.objectType = value
    }

    /**
     * @param value Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
     */
    @JvmName("dixgugiolcvsxokc")
    public suspend fun resourceID(`value`: Output<String>) {
        this.resourceID = value
    }

    /**
     * @param value Location of datasource.
     */
    @JvmName("ukvghclijnewmyay")
    public suspend fun resourceLocation(`value`: Output<String>) {
        this.resourceLocation = value
    }

    /**
     * @param value Unique identifier of the resource in the context of parent.
     */
    @JvmName("ltdfvfitqpnadphs")
    public suspend fun resourceName(`value`: Output<String>) {
        this.resourceName = value
    }

    /**
     * @param value Resource Type of Datasource.
     */
    @JvmName("xsbhbbbneohhahnu")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value Uri of the resource.
     */
    @JvmName("gsbvhmlxvstdqxkp")
    public suspend fun resourceUri(`value`: Output<String>) {
        this.resourceUri = value
    }

    /**
     * @param value DatasourceType of the resource.
     */
    @JvmName("wnwosinvdlkjtupy")
    public suspend fun datasourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.datasourceType = mapped
    }

    /**
     * @param value Type of Datasource object, used to initialize the right inherited type
     */
    @JvmName("nineymrdegqcrixa")
    public suspend fun objectType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.objectType = mapped
    }

    /**
     * @param value Full ARM ID of the resource. For azure resources, this is ARM ID. For non azure resources, this will be the ID created by backup service via Fabric/Vault.
     */
    @JvmName("oqycdwxkfqylgbfk")
    public suspend fun resourceID(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceID = mapped
    }

    /**
     * @param value Location of datasource.
     */
    @JvmName("fogteephxyrduoop")
    public suspend fun resourceLocation(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceLocation = mapped
    }

    /**
     * @param value Unique identifier of the resource in the context of parent.
     */
    @JvmName("bnvtknyqxbwlaxoh")
    public suspend fun resourceName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceName = mapped
    }

    /**
     * @param value Resource Type of Datasource.
     */
    @JvmName("hqevcwxkyxeeegtc")
    public suspend fun resourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value Uri of the resource.
     */
    @JvmName("nrypdgtxamthpsni")
    public suspend fun resourceUri(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceUri = mapped
    }

    internal fun build(): DatasourceSetArgs = DatasourceSetArgs(
        datasourceType = datasourceType,
        objectType = objectType,
        resourceID = resourceID ?: throw PulumiNullFieldException("resourceID"),
        resourceLocation = resourceLocation,
        resourceName = resourceName,
        resourceType = resourceType,
        resourceUri = resourceUri,
    )
}
